/************************************************************************/
/*																		*/
/*		   H S A _ H E L P . C - Help Command for HSA Libraries			*/
/*																		*/
/************************************************************************/

/************************************************************************/
/*																		*/
/*			  Copyright (c) Hardwood Software Associates 1987			*/
/*																		*/
/*					   Hardwood Software Associates						*/
/*							  364 Benson Road							*/
/*						   Northbridge, Ma 01534						*/
/*																		*/
/************************************************************************/

/************************************************************************
 *			H S A _ H E L P . C    E D I T    L O G
 *
 * $Log:   D:/crt/vcs/hsa_help.c_v  $
 *	
 *	   Rev 1.3   09 Apr 1989 17:37:38   R. Evans
 *	Support for 43 & 50 line modes
 *	
 *	   Rev 1.2   14 Feb 1988 10:52:12   R. Evans
 *	Changes for split library HSA_TEXT & HSA_WIN
 *	
 *	   Rev 1.1   07 Nov 1987 15:07:42   R. Evans
 *	get_char defined in w_menu1
 *	Add mouse support
 *	
 *	   Rev 1.0   11 Aug 1987 12:25:04   R. Evans
 *	Initial revision.
 *
 ************************************************************************/

/************************************************************************
 *													+-------------------+
 *	Author: R. Evans								| F U N C T I O N S |
 *	Date:	June, 1987								+-------------------+
 *
 ************** HSA_HELP - Displays help for HSA_TEXT Library on screen
 * SYNOPSIS:
 *				hsa_help [b] [43] [50]
 * DESCRIPTION:
 *				HSA_HELP displays a menu of all HSA_TEXT routines and
 *				displays help for the selected routine.  The file
 *				HSA_TEXT.HLP must be available in the current directory.
 * NOTE:
 *				If there is a "b" on the command line the BIOS mode of
 *				display is used; otherwise the direct mode is used.
 *				If there is a 43 on the command line then 43 lines used.
 *				If there is a 50 on the command line then 50 lines used.
 *
 ************************************************************************
 *				H E L P   F I L E   S T R U C T U R E
 *
 * The help file consists of two portions.
 * The top portion contains the menu entries.  Each entry is on a separate
 * line and may be no longer than 15 characters.  This portion is terminated
 * by a line containig a single form feed.
 * The second portion contains the help screens.  Each help screen begins
 * with a line that starts with a formfedd followed by all of the menu items
 * to which the screen applies.  The second line is displayed in the top
 * line of the menu.  Following this is the help screen.  The help screen
 * must contain no more than 23 or 41 or 48 lines of information.
 * The help file is terminated by a line with a form feed.
 *
 ************************************************************************/

#define LINT_ARGS

#include "hsa_tx.h"
#include "hsa_w.h"
#include <string.h>
#include <ctype.h>

#define EOS		'\0'

FILE *help;										/* Help file pointer */
char in_buffer[180];							/* Help file buffer */
char sel_buffer[16];							/* Selected module */

main (argc,argv)
int argc;
char **argv;
{
int selected;									/* Selection return */
WIN *win;										/* Window data Pointer */
int w_attr;										/* Menu window attribute */
int border_attr;								/* Menu border attribute */
int help_w_attr;								/* Help window attribute */
int help_border_attr;							/* Help window border attribute */

if (tx_state () == MONOCHROME)					/* Set attributes */
	{
	help_w_attr = w_attr = SCR_NORM;
	help_border_attr = border_attr = SCR_BOLD;
	}
else
	{
	help_w_attr = MAKE_ATTR (SCR_BLACK,SCR_CYAN);
	help_border_attr = MAKE_ATTR ((SCR_INTENSE_BIT|SCR_WHITE),SCR_CYAN);
	w_attr = MAKE_ATTR (SCR_BLACK,SCR_MAGENTA);
	border_attr = MAKE_ATTR ((SCR_INTENSE_BIT|SCR_WHITE),SCR_MAGENTA);
	}

tx_direct ();									/* Set screen access mode */
while (argc--)
	{
	if (toupper (*argv[argc]) == 'B')
		tx_bios ();
	if (*argv[argc] == '4')
		tx_43 ();								/* Set to 43 line mode */
	if (*argv[argc] == '5')
		tx_50 ();								/* Set to 50 line mode */
	}

if ( (help = fopen ("hsa.hlp","r")) == NULL)
	{											/* Open the help file */
	tx_str_c ("Help file not found.");
	tx_25 ();									/* Back to 25 lines */
	exit (77);
	}

for (;;)										/* Go foreever */
	{											/* Create help menu */
	register int row;							/* Row counter for help display */
	if (w_menu1_open (1,5,tx_no_row()-3,70,w_attr,border_attr,DOUBLE_LINES,15,
						"HSA Library Help","Hardwood Software Associates",1))
		{
		tx_str_c ("Error creating help window.");
		tx_25 ();								/* Back to 25 lines */
		exit (77);
		}

	for (;;)										/* Generate menu */
		{
		get_help_line ();
		if (in_buffer[0] == '\f')
			break;
		if ( (selected = w_menu1_fill (in_buffer,sel_buffer)) )
			break;
		}
	if (!selected)								/* If nothing selected terminate menu */
		selected = w_menu1_fill (NULL,sel_buffer);

	if (toupper (selected) == 'Q' || strlen (sel_buffer) == 0)
		{										/* Done */
		tx_cur_show ();
		tx_25 ();								/* Back to 25 lines */
		exit (0);
		}

	win = w_open ((tx_no_row()-7)/2,20,5,34,SCR_BLINK,SCR_BOLD,SINGLE_LINES,0);
	w_str (win,1,5,"Scanning for help text");

	row=0;
	for (;;)									/* Find requested item */
		{
		get_help_line ();
		if (in_buffer[0] == '\f' && strstr (in_buffer,sel_buffer) != NULL)
			break;
		}
	w_close (win);
	if ( (win = w_open (0,0,tx_no_row(),80,help_w_attr,help_border_attr,DOUBLE_LINES,0)) == NULL)
		{
		tx_str_c ("Error on open of help window.");
		tx_25 ();								/* Back to 25 lines */
		exit (77);
		}
	tx_cur_hide ();								/* Display help */
	w_bot_msg (win,"Press any key to continue",MSG_LEFT);
	get_help_line ();
	w_top_msg (win,in_buffer,MSG_CENTER);
	while (get_help_line ())
		{
		if (in_buffer[0] == '\f')
			break;
		w_str (win,row++,0,in_buffer);
		}
	if (tx_mows_type ())
		while (tx_mows_button () == 0)
			;
	else 
		getch ();								/* Wait for user to read */
	w_close (win);
	rewind (help);
	}
} /* Of hsa_help */

/************************************************************************/
/*																		*/
/*			G E T _ H E L P _ L I N E - Get line from help file			*/
/*																		*/
/************************************************************************/

get_help_line ()
{
if (fgets (in_buffer,sizeof(in_buffer),help) == NULL)
	{
	tx_nl (); tx_b_b ();
	tx_str_c ("Premature end of help file, searching for ");
	tx_str_c (sel_buffer);
	exit (77);
	}
in_buffer[strlen(in_buffer)-1] = EOS;
} /* Of get_help_line */
